# Copyright (c) Meta Platforms, Inc. and affiliates.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# pyre-strict

import thrift.test.python_capi.serialized_dep.thrift_types as thrift_types

def make_serialized_struct(is_set: bool) -> thrift_types.SerializedStruct: ...
def make_serialized_union(set_string: bool) -> thrift_types.SerializedUnion: ...
def make_serialized_error(is_set: bool) -> thrift_types.SerializedError: ...
def make_marshal_struct(is_set: bool) -> thrift_types.MarshalError: ...
def make_marshal_union(set_string: bool) -> thrift_types.MarshalUnion: ...
def make_marshal_error(is_set: bool) -> thrift_types.MarshalError: ...
def make_unset_struct_serialized() -> thrift_types.SerializedStruct: ...
def make_unset_struct_marshal() -> thrift_types.MarshalStruct: ...
def make_unset_union_serialized() -> thrift_types.SerializedUnion: ...
def make_unset_union_marshal() -> thrift_types.MarshalUnion: ...
def make_unset_error_serialized() -> thrift_types.SerializedError: ...
def make_unset_error_marshal() -> thrift_types.MarshalError: ...
